/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: library.h,v 1.13 2002/04/01 14:49:22 jbaayen Exp $
 */

#ifndef __LIBRARY_H
#define __LIBRARY_H

#include <gtk/gtkwidget.h>

#include "node.h"

G_BEGIN_DECLS

#define TYPE_LIBRARY            (library_get_type ())
#define LIBRARY(obj)	        (GTK_CHECK_CAST ((obj), TYPE_LIBRARY, Library))
#define LIBRARY_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY, LibraryClass))
#define IS_LIBRARY(obj)	        (GTK_CHECK_TYPE ((obj), TYPE_LIBRARY))
#define IS_LIBRARY_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY))
#define LIBRARY_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), TYPE_LIBRARY, LibraryClass))

typedef struct _Library        		Library;
typedef struct _LibraryClass 		LibraryClass;

typedef struct _LibraryPrivate 		LibraryPrivate;

struct _Library
{
	GObject base;
	
	LibraryPrivate *priv;
};

struct _LibraryClass
{
	GObjectClass parent_class;

	/* signals */
	void (*node_created) (Library *l, Node *node);
	void (*node_changed) (Library *l, Node *node);
	void (*node_deleted) (Library *l, Node *node);
};

typedef enum
{
	LIBRARY_NODE_ROOT,
	LIBRARY_NODE_ARTIST,
	LIBRARY_NODE_ALBUM,
	LIBRARY_NODE_SONG
} LibraryNodeType;

GType            library_get_type       (void) G_GNUC_CONST;

Library         *library_new            (void);

void             library_release_brakes (Library *l);

Node            *library_add_uri        (Library *l, const gchar *uri);
void             library_remove_uri     (Library *l, const gchar *uri);

Node            *library_get_root       (Library *l);

Node		*library_node_from_id   (Library *l, int id);
Node            *library_search         (Library *l, const char *search_text);

Node		*library_get_all_albums (Library *l);
Node		*library_get_all_songs  (Library *l);

#define NODE_PROPERTY_NAME         "name"
#define NODE_PROPERTY_TYPE         "type"

#define SONG_PROPERTY_DATE         "date"
#define SONG_PROPERTY_GENRE        "genre"
#define SONG_PROPERTY_COMMENT      "comment"
#define SONG_PROPERTY_CODEC_INFO   "codecinfo"
#define SONG_PROPERTY_TRACK_NUMBER "tracknum"
#define SONG_PROPERTY_BIT_RATE     "bitrate"
#define SONG_PROPERTY_FILE_SIZE    "filesize"
#define SONG_PROPERTY_LENGTH       "length"
#define SONG_PROPERTY_MTIME        "mtime"
#define SONG_PROPERTY_URI          "uri"

G_END_DECLS

#endif /* __LIBRARY_H */
