/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: node.h,v 1.14 2002/04/01 14:49:22 jbaayen Exp $
 */

#ifndef __NODE_H
#define __NODE_H

#include <gtk/gtk.h>
#include <glib-object.h>
#include <libxml/tree.h>

G_BEGIN_DECLS

typedef struct _Node          Node;
typedef struct _NodeClass     NodeClass;

typedef struct _NodeDetails   NodeDetails;

#define TYPE_NODE             (node_get_type ())
#define NODE(obj)             (GTK_CHECK_CAST ((obj), TYPE_NODE, Node))
#define NODE_CLASS(klass)     (GTK_CHECK_CLASS_CAST ((klass), TYPE_NODE, NodeClass))
#define IS_NODE(obj)          (GTK_CHECK_TYPE ((obj), TYPE_NODE))
#define IS_NODE_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((klass), TYPE_NODE))

struct _Node
{
        GObject base;

        NodeDetails *details;
};

struct _NodeClass
{
        GObjectClass parent_class;

	/* Signals */
	void (*destroyed) (Node *node);
};

typedef void (*ActionNotifier)    (Node *node, gint level, gpointer data);

GType        node_get_type            (void) G_GNUC_CONST;

Node        *node_new                 (const char *xml_name);

GList       *node_get_parents         (Node *node);
void         node_set_grandparent     (Node *node, Node *granny);
Node        *node_get_grandparent     (Node *node);
GList       *node_get_children        (Node *node);
const gchar *node_get_string_property (Node *node, const gchar *property);
gint         node_get_int_property    (Node *node, const gchar *property);
void         node_append              (Node *parent, Node *node);
void         node_remove              (Node *node,
				       gint h_level,
				       gint l_level,
				       ActionNotifier func,
				       gpointer data);
void         node_set_string_property (Node *node,
				       const gchar *name,
				       gchar *value);
void         node_set_int_property    (Node *node,
				       const gchar *name,
				       gint value);
gboolean     node_has_child           (Node *node,
				       Node *child);

void         node_set_xml_name        (Node *node, const char *save_name);
xmlNodePtr   node_save_to_xml         (Node *node, Node *grandparent,
				       xmlNodePtr parent, gboolean save_children);

G_END_DECLS

#endif /* __NODE_H */
