/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: playlist-ui.h,v 1.11 2002/04/11 15:31:40 jbaayen Exp $
 */

#ifndef __PLAYLIST_UI_H
#define __PLAYLIST_UI_H

#include "ui.h"
#include "library.h"
#include "source-manager.h"

G_BEGIN_DECLS

#define TYPE_PLAYLIST_UI            (playlist_ui_get_type ())
#define PLAYLIST_UI(obj)	    (GTK_CHECK_CAST ((obj), TYPE_PLAYLIST_UI, PlaylistUI))
#define PLAYLIST_UI_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), TYPE_PLAYLIST_UI, PlaylistUIClass))
#define IS_PLAYLIST_UI(obj)	    (GTK_CHECK_TYPE ((obj), TYPE_PLAYLIST_UI))
#define IS_PLAYLIST_UI_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TYPE_PLAYLIST_UI))
#define PLAYLIST_UI_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), TYPE_PLAYLIST_UI, PlaylistUIClass))

typedef struct _PlaylistUI        	PlaylistUI;
typedef struct _PlaylistUIClass 	PlaylistUIClass;

typedef struct _PlaylistUIPrivate 	PlaylistUIPrivate;

struct _PlaylistUI
{
	GObject base;
	
	PlaylistUIPrivate *priv;
};

struct _PlaylistUIClass
{
	GObjectClass parent_class;

	/* Signals */
	void (*start_playing) (PlaylistUI *l);
	void (*stop_playing)  (PlaylistUI *l);
	void (*removed)       (PlaylistUI *l, gint id);
};

GType        playlist_ui_get_type          (void) G_GNUC_CONST;

PlaylistUI  *playlist_ui_new               (SourceManager *manager);

int          playlist_ui_get_source_id     (PlaylistUI *l);
void         playlist_ui_load_from_file    (PlaylistUI *l, const gchar *fn);
const gchar *playlist_ui_get_file          (PlaylistUI *l);
void         playlist_ui_set_name          (PlaylistUI *l, const gchar *name);
void         playlist_ui_add_nodes         (PlaylistUI *l, GList *nodes);
GList       *playlist_ui_get_selection     (PlaylistUI *l);
void         playlist_ui_start_editing     (PlaylistUI *l);

G_END_DECLS

#endif /* __PLAYLIST_UI_H */
