/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: songs-view.h,v 1.25 2002/04/10 20:50:39 jbaayen Exp $
 */

#ifndef __SONGS_VIEW_H
#define __SONGS_VIEW_H

#include "ui.h"
#include "library.h"
#include "treeview-utils.h"

G_BEGIN_DECLS

#define TYPE_SONGS_VIEW            (songs_view_get_type ())
#define SONGS_VIEW(obj)	     	   (GTK_CHECK_CAST ((obj), TYPE_SONGS_VIEW, SongsView))
#define SONGS_VIEW_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), TYPE_SONGS_VIEW, SongsViewClass))
#define IS_SONGS_VIEW(obj)	   (GTK_CHECK_TYPE ((obj), TYPE_SONGS_VIEW))
#define IS_SONGS_VIEW_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TYPE_SONGS_VIEW))
#define SONGS_VIEW_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), TYPE_SONGS_VIEW, SongsViewClass))

typedef struct _SongsView        	SongsView;
typedef struct _SongsViewClass 		SongsViewClass;

typedef struct _SongsViewPrivate 	SongsViewPrivate;

struct _SongsView
{
	GtkHBox parent;
	
	SongsViewPrivate *priv;
};

struct _SongsViewClass
{
	GtkHBoxClass parent_class;

	/* Signals */
	void (*row_activated)             (SongsView *l, Node *node);
	void (*row_remove_request)        (SongsView *l, GList *nodes);
	void (*rewind_available)          (SongsView *l, gboolean available);
	void (*forward_available)         (SongsView *l, gboolean available);
	void (*selection_available)       (SongsView *l, gboolean available);
};

typedef enum
{
	SONGS_VIEW_NODE_STATE_PLAYING,
	SONGS_VIEW_NODE_STATE_PAUSED,
	SONGS_VIEW_NODE_STATE_STOPPED
} SongsViewNodeState;

GType                songs_view_get_type             (void) G_GNUC_CONST;

GtkWidget           *songs_view_new                  (void);

Node                *songs_view_get_first            (SongsView *l);
Node                *songs_view_get_next             (SongsView *l);
Node                *songs_view_get_prev             (SongsView *l);

void                 songs_view_set_node_state       (SongsView *l, Node *node,
						      SongsViewNodeState state);

void                 songs_view_add_node             (SongsView *l, Node *node);
void                 songs_view_update_node          (SongsView *l, Node *node);
void                 songs_view_remove_node          (SongsView *l, Node *node);

void                 songs_view_filter               (SongsView *l, Node *node, Node *grandparent);

GList               *songs_view_get_checked_nodes    (SongsView *l);
GList               *songs_view_get_all_nodes        (SongsView *l);
GList               *songs_view_get_shown_nodes      (SongsView *l);
GList               *songs_view_get_selected_nodes   (SongsView *l);

void                 songs_view_check_state          (SongsView *l);

gint		     songs_view_num_rows             (SongsView *l);

void		     songs_view_set_repeat           (SongsView *l, gboolean repeat);
void		     songs_view_set_shuffle          (SongsView *l, gboolean shuffle);

gchar               *songs_view_build_status_message (SongsView *l);

void                 songs_view_select_nodes         (SongsView *l, GList *nodes);

/* prefs */
#define CONF_SONGS_VIEW_COLUMNS  "/apps/rhythmbox/SongsView/columns"

G_END_DECLS

#endif /* __SONGS_VIEW_H */
