/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: source-manager.h,v 1.3 2002/04/01 14:49:22 jbaayen Exp $
 */

#ifndef __SOURCE_MANAGER_H
#define __SOURCE_MANAGER_H

#include <glib-object.h>

G_BEGIN_DECLS

#define TYPE_SOURCE_MANAGER            (source_manager_get_type ())
#define SOURCE_MANAGER(obj)	       (GTK_CHECK_CAST ((obj), TYPE_SOURCE_MANAGER, SourceManager))
#define SOURCE_MANAGER_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_MANAGER, SourceManagerClass))
#define IS_SOURCE_MANAGER(obj)	       (GTK_CHECK_TYPE ((obj), TYPE_SOURCE_MANAGER))
#define IS_SOURCE_MANAGER_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_MANAGER))
#define SOURCE_MANAGER_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), TYPE_SOURCE_MANAGER, SourceManagerClass))

typedef struct _SourceManager        	SourceManager;
typedef struct _SourceManagerClass 	SourceManagerClass;

typedef struct _SourceManagerPrivate 	SourceManagerPrivate;

#include "ui.h"
#include "queue.h"
#include "library.h"

struct _SourceManager
{
	GObject base;
	
	SourceManagerPrivate *priv;
};

struct _SourceManagerClass
{
	GObjectClass parent_class;

	/* Signals */
	void (*clipboard_available) (SourceManager *m, gboolean available);
	void (*stop_playing)        (SourceManager *m, gpointer exception);
};

GType            source_manager_get_type         (void) G_GNUC_CONST;

SourceManager   *source_manager_new              (Queue *queue, UI *ui, Library *library);

void             source_manager_set_ui           (SourceManager *m, UI *ui);
UI              *source_manager_get_ui           (SourceManager *m);

void             source_manager_set_queue        (SourceManager *m, Queue *queue);
Queue           *source_manager_get_queue        (SourceManager *m);

void             source_manager_set_library      (SourceManager *m, Library *library);
Library         *source_manager_get_library      (SourceManager *m);

void             source_manager_set_clipboard    (SourceManager *m, GList *nodes);
GList           *source_manager_get_clipboard    (SourceManager *m);

/* prefs */
#define CONF_SHUFFLE		 "/apps/rhythmbox/SourceManager/shuffle"
#define CONF_REPEAT              "/apps/rhythmbox/SourceManager/repeat"

G_END_DECLS

#endif /* __SOURCE_MANAGER_H */
