/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: state-manager.h,v 1.4 2002/04/11 15:31:40 jbaayen Exp $
 */

#ifndef __STATE_MANAGER_H
#define __STATE_MANAGER_H

#include <glib-object.h>

#include "queue.h"
#include "songs-view.h"
#include "node.h"

G_BEGIN_DECLS

#define TYPE_STATE_MANAGER            (state_manager_get_type ())
#define STATE_MANAGER(obj)	      (GTK_CHECK_CAST ((obj), TYPE_STATE_MANAGER, StateManager))
#define STATE_MANAGER_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), TYPE_STATE_MANAGER, StateManagerClass))
#define IS_STATE_MANAGER(obj)	      (GTK_CHECK_TYPE ((obj), TYPE_STATE_MANAGER))
#define IS_STATE_MANAGER_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TYPE_STATE_MANAGER))
#define STATE_MANAGER_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), TYPE_STATE_MANAGER, StateManagerClass))

typedef struct _StateManager        	StateManager;
typedef struct _StateManagerClass 	StateManagerClass;

typedef struct _StateManagerPrivate 	StateManagerPrivate;

struct _StateManager
{
	GObject base;
	
	StateManagerPrivate *priv;
};

struct _StateManagerClass
{
	GObjectClass parent_class;

	/* Signals */
	void (*start_playing) (StateManager *m);
	void (*stop_playing)  (StateManager *m);
};

GType         state_manager_get_type         (void) G_GNUC_CONST;

StateManager *state_manager_new              (Queue *queue, UI *ui, SongsView *view, int id);

void          state_manager_set_active       (StateManager *m, gboolean active);
gboolean      state_manager_get_active       (StateManager *m);

void          state_manager_set_playing_node (StateManager *m, Node *node);
Node         *state_manager_get_playing_node (StateManager *m);

void          state_manager_set_paused       (StateManager *m, gboolean paused);
gboolean      state_manager_get_paused       (StateManager *m);

G_END_DECLS

#endif /* __STATE_MANAGER_H */
