/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: queue.h,v 1.12 2002/04/01 14:49:22 jbaayen Exp $
 */

#ifndef __QUEUE_H
#define __QUEUE_H

#include <glib-object.h>

G_BEGIN_DECLS

#define TYPE_QUEUE            (queue_get_type ())
#define QUEUE(obj)	      (GTK_CHECK_CAST ((obj), TYPE_QUEUE, Queue))
#define QUEUE_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), TYPE_QUEUE, QueueClass))
#define IS_QUEUE(obj)	      (GTK_CHECK_TYPE ((obj), TYPE_QUEUE))
#define IS_QUEUE_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TYPE_QUEUE))
#define QUEUE_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), TYPE_QUEUE, QueueClass))

typedef struct _Queue        		Queue;
typedef struct _QueueClass 		QueueClass;

typedef struct _QueuePrivate 		QueuePrivate;

typedef enum
{
	QUEUE_STATE_STOPPED,
	QUEUE_STATE_PLAYING,
	QUEUE_STATE_PAUSED
} QueueState;

GType queue_state_get_type (void);
#define QUEUE_TYPE_STATE (queue_state_get_type ())

struct _Queue
{
	GObject base;
	
	QueuePrivate *priv;
};

struct _QueueClass
{
	GObjectClass parent_class;

	/* signals */
	void (*request_next)  (Queue *q);
	void (*state_changed) (Queue *q, QueueState state);
};

GType       queue_get_type         (void) G_GNUC_CONST;

Queue      *queue_new              (void);

/* state */
void        queue_set_state        (Queue *q, QueueState state);
QueueState  queue_get_state	   (Queue *q);

/* currently loaded uri */
void        queue_set_current_uri  (Queue *q, const char *uri,
				    long total_seconds);
const char *queue_get_current_uri  (Queue *q);

/* song information */
long        queue_get_elapsed_time (Queue *q);

/* volume */
void        queue_set_volume       (Queue *q, float volume);
float       queue_get_volume       (Queue *q);

/* progress (seeking) */
void        queue_set_progress     (Queue *q, float progress);
float       queue_get_progress     (Queue *q);

G_END_DECLS

#endif /* __QUEUE_H */
