/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: rhythmbox-automation.c,v 1.6 2002/04/01 14:57:44 jbaayen Exp $
 */

#include "rhythmbox-automation.h"
#include "RhythmBoxAutomation.h"
#include "main.h"
#include "applet.h"

#include <bonobo/bonobo-generic-factory.h>
#include <bonobo/bonobo-main.h>
#include <bonobo/bonobo-context.h>

static void impl_rhythmbox_automation_setVisible (PortableServer_Servant _servant,
				                  CORBA_boolean visible,
				                  CORBA_Environment * ev);
static void impl_rhythmbox_automation_play (PortableServer_Servant _servant,
				            CORBA_Environment * ev);
static void impl_rhythmbox_automation_pause (PortableServer_Servant _servant,
				             CORBA_Environment * ev);
static void impl_rhythmbox_automation_rewind (PortableServer_Servant _servant,
				              CORBA_Environment * ev);
static void impl_rhythmbox_automation_forward (PortableServer_Servant _servant,
				               CORBA_Environment * ev);
static void impl_rhythmbox_automation_newApplet (PortableServer_Servant _servant,
				                 CORBA_Environment * ev);
static void impl_rhythmbox_automation_addFile (PortableServer_Servant _servant,
				               CORBA_string filename,
				               CORBA_Environment * ev);
static void impl_rhythmbox_automation_quit (PortableServer_Servant _servant,
				            CORBA_Environment * ev);
static void rhythmbox_automation_class_init (RhythmBoxAutomationClass *klass);
static void rhythmbox_automation_init (RhythmBoxAutomation *a);
static void rhythmbox_automation_object_finalize (GObject *object);
static BonoboObject * rhythmbox_automation_factory (BonoboGenericFactory *this_factory,
			                            const char *iid,
			                            gpointer user_data);

static GObjectClass *rhythmbox_automation_parent_class;

static BonoboObject *
rhythmbox_automation_factory (BonoboGenericFactory *this_factory,
			   const char *iid,
			   gpointer user_data)
{
        RhythmBoxAutomation *a;
        
        a  = g_object_new (RHYTHMBOX_AUTOMATION_TYPE, NULL);

        return BONOBO_OBJECT (a);
}

BonoboObject *
rhythmbox_automation_new (void)
{
	BonoboGenericFactory *factory;

	factory = bonobo_generic_factory_new ("OAFIID:GNOME_RhythmBox_Automation_Factory",
					      rhythmbox_automation_factory,
					      NULL);

	return BONOBO_OBJECT (factory);
}

static void
impl_rhythmbox_automation_setVisible (PortableServer_Servant _servant,
				      CORBA_boolean visible,
				      CORBA_Environment * ev)
{
	ui_set_visible (rhythmbox->ui, visible);
}

static void
impl_rhythmbox_automation_play (PortableServer_Servant _servant,
				CORBA_Environment * ev)
{
	ui_play (rhythmbox->ui);
}

static void
impl_rhythmbox_automation_pause (PortableServer_Servant _servant,
				 CORBA_Environment * ev)
{
	ui_pause (rhythmbox->ui);
}

static void
impl_rhythmbox_automation_rewind (PortableServer_Servant _servant,
				  CORBA_Environment * ev)
{
	ui_rewind (rhythmbox->ui);
}

static void
impl_rhythmbox_automation_forward (PortableServer_Servant _servant,
				   CORBA_Environment * ev)
{
	ui_forward (rhythmbox->ui);
}

static void
impl_rhythmbox_automation_newApplet (PortableServer_Servant _servant,
				     CORBA_Environment * ev)
{
	applet_new (rhythmbox);
}

static void
impl_rhythmbox_automation_addFile (PortableServer_Servant _servant,
				   CORBA_string filename,
				   CORBA_Environment * ev)
{
	library_add_uri (rhythmbox->library, filename);
}

static void
impl_rhythmbox_automation_quit (PortableServer_Servant _servant,
                                CORBA_Environment * ev)
{
	rhythmbox_exit (rhythmbox);
}

static void
rhythmbox_automation_class_init (RhythmBoxAutomationClass *klass)
{
        GObjectClass *object_class = (GObjectClass *) klass;
        POA_GNOME_RhythmBoxAutomation__epv *epv = &klass->epv;

        rhythmbox_automation_parent_class = g_type_class_peek_parent (klass);

        object_class->finalize = rhythmbox_automation_object_finalize;

        /* connect implementation callbacks */
	epv->setVisible    = impl_rhythmbox_automation_setVisible;
	epv->play          = impl_rhythmbox_automation_play;
	epv->pause         = impl_rhythmbox_automation_pause;
	epv->rewind        = impl_rhythmbox_automation_rewind;
	epv->forward       = impl_rhythmbox_automation_forward;
	epv->newApplet     = impl_rhythmbox_automation_newApplet;
	epv->addFile       = impl_rhythmbox_automation_addFile;
	epv->quit          = impl_rhythmbox_automation_quit;
}

static void
rhythmbox_automation_init (RhythmBoxAutomation *c) 
{
}

static void
rhythmbox_automation_object_finalize (GObject *object)
{
        RhythmBoxAutomation *a = RHYTHMBOX_AUTOMATION (object);

        rhythmbox_automation_parent_class->finalize (G_OBJECT (a));
}

BONOBO_TYPE_FUNC_FULL (
        RhythmBoxAutomation,                    
        GNOME_RhythmBoxAutomation, 
        BONOBO_TYPE_OBJECT,           
        rhythmbox_automation);
