/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __CONTROL_BAR_H
#define __CONTROL_BAR_H

#include <gtk/gtkwidget.h>
#include <glade.h>

#define TYPE_CONTROL_BAR            (control_bar_get_type ())
#define CONTROL_BAR(obj)	    (GTK_CHECK_CAST ((obj), TYPE_CONTROL_BAR, ControlBar))
#define CONTROL_BAR_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), TYPE_CONTROL_BAR, ControlBarClass))
#define IS_CONTROL_BAR(obj)	    (GTK_CHECK_TYPE ((obj), TYPE_CONTROL_BAR))
#define IS_CONTROL_BAR_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TYPE_CONTROL_BAR))
#define CONTROL_BAR_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), TYPE_CONTROL_BAR, ControlBarClass))

typedef struct _ControlBar          ControlBar;
typedef struct _ControlBarClass     ControlBarClass;

typedef struct _ControlBarPrivate   ControlBarPrivate;

#include "ui.h"

struct _ControlBar
{
	GObject base;
	
	ControlBarPrivate *priv;

	/* parent window */
	UI *ui;

	/* state */
	UIState state;
};

typedef enum
{
	CONTROL_BAR_PLAY_ACTION_PAUSE,
	CONTROL_BAR_PLAY_ACTION_PLAY,
	CONTROL_BAR_PLAY_ACTION_STOP
} ControlBarPlayAction;

struct _ControlBarClass
{
	GObjectClass parent_class;

	/* signals */
	void (*play_clicked)     (ControlBar *t, ControlBarPlayAction action);
	void (*rewind_clicked)   (ControlBar *t);
	void (*forward_clicked)  (ControlBar *t);
	void (*search_activate)  (ControlBar *t, gchar *text);
	void (*volume_changed)   (ControlBar *t, gfloat volume);
	void (*progress_changed) (ControlBar *t, gfloat progress);
};

GType control_bar_get_type (void) G_GNUC_CONST;

ControlBar* control_bar_new (GladeXML *gxml);

void control_bar_set_ui                    (ControlBar *t, UI *ui);
UI  *control_bar_get_ui                    (ControlBar *t);

void control_bar_init_interface            (ControlBar *t, GladeXML *gxml);

void control_bar_set_rewind_sensitive      (ControlBar *t, gboolean sensitive);
gboolean control_bar_get_rewind_sensitive  (ControlBar *t);

void control_bar_set_forward_sensitive     (ControlBar *t, gboolean sensitive);
gboolean control_bar_get_forward_sensitive (ControlBar *t);

void control_bar_set_state                 (ControlBar *t, UIState state);
UIState control_bar_get_state              (ControlBar *t);

void control_bar_merge_widgets             (ControlBar *t,
					    GList *widgets);
GtkWidget *control_bar_new_action_button (ControlBar *t,
					  const char *label,
					  const char *tooltip,
					  GdkPixbuf *icon,
					  gboolean toggle);

void control_bar_set_lcd_song              (ControlBar *t, const char *title, const char *artist, const char *uri);
void control_bar_set_lcd_time              (ControlBar *t,
					    long elapsed,
					    float progress);

void control_bar_set_volume                (ControlBar *t, gfloat volume);
gfloat control_bar_get_volume              (ControlBar *t);

void control_bar_clear_search_entry        (ControlBar *t);

#endif /* __CONTROL_BAR_H */
