/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <string.h>
#include <libgnome/gnome-i18n.h>

#include "misc.h"
#include "icons.h"

GtkIconSize RHYTHMBOX_ICON_SIZE_CONTROL_BAR;
GtkIconSize RHYTHMBOX_ICON_SIZE_LCD;
GtkIconSize RHYTHMBOX_ICON_SIZE_ACTION;

/**
 * init_icon_factory: load stock icons
 */
void
init_icon_factory (void)
{
	GtkIconFactory *factory;
	gint i;

	GtkStockItem items[] = {
		{ RHYTHMBOX_STOCK_FORWARD,         N_("Forward"),         0, 0, NULL },
		{ RHYTHMBOX_STOCK_REWIND,          N_("Rewind"),          0, 0, NULL },
		{ RHYTHMBOX_STOCK_PLAY,            N_("Play"),            0, 0, NULL },
		{ RHYTHMBOX_STOCK_PAUSE,           N_("Pause"),           0, 0, NULL },
		{ RHYTHMBOX_STOCK_STOP,            N_("Stop"),            0, 0, NULL },
		{ RHYTHMBOX_STOCK_LCD_TOGGLE,      N_("Toggle"),          0, 0, NULL },
		{ RHYTHMBOX_STOCK_VOLUME,          N_("Volume"),          0, 0, NULL },
		{ RHYTHMBOX_STOCK_VOLUME_OFF,      N_("Mute"),            0, 0, NULL },
		{ RHYTHMBOX_STOCK_SHUFFLE,         N_("Shuffle"),         0, 0, NULL },
		{ RHYTHMBOX_STOCK_REPEAT,          N_("Repeat"),          0, 0, NULL },
		{ RHYTHMBOX_STOCK_LIBRARY,         N_("Library"),         0, 0, NULL },
		{ RHYTHMBOX_STOCK_PLAYLIST,        N_("Playlist"),        0, 0, NULL },
		{ RHYTHMBOX_STOCK_ACTION_PLAYLIST, N_("Burn a CD"),       0, 0, NULL },
		{ RHYTHMBOX_STOCK_ACTION_LIBRARY,  N_("Toggle browsing"), 0, 0, NULL }
	};

	gtk_stock_add (items, G_N_ELEMENTS (items));

	factory = gtk_icon_factory_new ();
	gtk_icon_factory_add_default (factory);

	for (i = 0; i < (gint) G_N_ELEMENTS (items); i++)
	{
		GtkIconSet *icon_set;
		GdkPixbuf *pixbuf;
		gchar *fn, *fn2;

		fn = g_strconcat (items[i].stock_id, ".png", NULL);
		fn2 = user_file (fn, FALSE);
		pixbuf = gdk_pixbuf_new_from_file (fn2, NULL);
		g_free (fn2);
		g_free (fn);

		icon_set = gtk_icon_set_new_from_pixbuf (pixbuf);
		gtk_icon_factory_add (factory, items[i].stock_id, icon_set);
		gtk_icon_set_unref (icon_set);
		
		g_object_unref (G_OBJECT (pixbuf));
	}

	RHYTHMBOX_ICON_SIZE_CONTROL_BAR =
		gtk_icon_size_register ("rhythmbox-icon-size-control-bar", 36, 36);
	RHYTHMBOX_ICON_SIZE_LCD =
		gtk_icon_size_register ("rhythmbox-icon-size-lcd", 10, 10);
	RHYTHMBOX_ICON_SIZE_ACTION =
		gtk_icon_size_register ("rhythmbox-icon-size-action", 48, 48);

	g_object_unref (G_OBJECT (factory));
}
