/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __SOURCELIST_H
#define __SOURCELIST_H

#include <gtk/gtkwidget.h>
#include <glade.h>

#define TYPE_SOURCELIST            (sourcelist_get_type ())
#define SOURCELIST(obj)	           (GTK_CHECK_CAST ((obj), TYPE_SOURCELIST, Sourcelist))
#define SOURCELIST_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), TYPE_SOURCELIST, SourcelistClass))
#define IS_SOURCELIST(obj)	   (GTK_CHECK_TYPE ((obj), TYPE_SOURCELIST))
#define IS_SOURCELIST_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TYPE_SOURCELIST))
#define SOURCELIST_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), TYPE_SOURCELIST, SourcelistClass))

typedef struct _Sourcelist        		Sourcelist;
typedef struct _SourcelistClass 		SourcelistClass;

typedef struct _SourcelistPrivate 		SourcelistPrivate;

#include "ui.h"

struct _Sourcelist
{
	GObject base;
	
	SourcelistPrivate *priv;

	/* parent window */
	UI *ui;
};

struct _SourcelistClass
{
	GObjectClass parent_class;

	/* signals */
	void (*source_selected) (Sourcelist *s, int id);
	void (*source_deleted)  (Sourcelist *s, int id);
	void (*source_edited)   (Sourcelist *s, int id, gchar *text);
};

GType sourcelist_get_type            (void) G_GNUC_CONST;

Sourcelist *sourcelist_new           (GladeXML *gxml);

void sourcelist_set_ui               (Sourcelist *s, UI *ui);
UI  *sourcelist_get_ui               (Sourcelist *s);

void sourcelist_init_interface       (Sourcelist *s, GladeXML *gxml);

int  sourcelist_append_source        (Sourcelist *s, GtkWidget *source);
void sourcelist_select_source        (Sourcelist *s, int id);
void sourcelist_remove_source        (Sourcelist *s, int id);
void sourcelist_source_set_name      (Sourcelist *s, int id, const gchar *name);
void sourcelist_source_set_priority  (Sourcelist *s, int id, int priority);
void sourcelist_source_set_icon      (Sourcelist *s, int id, GdkPixbuf *icon);
void sourcelist_source_set_editable  (Sourcelist *s, int id, gboolean editable);
int  sourcelist_get_selected_source  (Sourcelist *s);
void sourcelist_source_start_editing (Sourcelist *s, int id);
void sourcelist_source_set_playing   (Sourcelist *s, int id, gboolean playing);

#endif /* __SOURCELIST_H */
