/*  RhythmBox
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __STATUSBAR_H
#define __STATUSBAR_H

#include <gtk/gtkwidget.h>
#include <glade.h>

#define TYPE_STATUSBAR            (statusbar_get_type ())
#define STATUSBAR(obj)	          (GTK_CHECK_CAST ((obj), TYPE_STATUSBAR, Statusbar))
#define STATUSBAR_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), TYPE_STATUSBAR, StatusbarClass))
#define IS_STATUSBAR(obj)	  (GTK_CHECK_TYPE ((obj), TYPE_STATUSBAR))
#define IS_STATUSBAR_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TYPE_STATUSBAR))
#define STATUSBAR_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), TYPE_STATUSBAR, StatusbarClass))

typedef struct _Statusbar        	Statusbar;
typedef struct _StatusbarClass 		StatusbarClass;

typedef struct _StatusbarPrivate 	StatusbarPrivate;

#include "ui.h"

struct _Statusbar
{
	GObject base;
	
	StatusbarPrivate *priv;

	/* parent window */
	UI *ui;
};

struct _StatusbarClass
{
	GObjectClass parent_class;

	/* signals */
	void (*shuffle_clicked)      (Statusbar *s, gboolean shuffle);
	void (*repeat_clicked)       (Statusbar *s, gboolean repeat);
	void (*new_playlist_clicked) (Statusbar *s);
};

GType statusbar_get_type           (void) G_GNUC_CONST;

Statusbar* statusbar_new           (GladeXML *gxml);

void statusbar_init_interface      (Statusbar *s, GladeXML *xml);

void statusbar_set_ui              (Statusbar *s, UI *ui);
UI  *statusbar_get_ui              (Statusbar *s);

void statusbar_set_message         (Statusbar *s, const gchar *message);
const gchar *statusbar_get_message (Statusbar *s);

void statusbar_set_shuffle         (Statusbar *s, gboolean shuffle);
gboolean statusbar_get_shuffle     (Statusbar *s);

void statusbar_set_repeat          (Statusbar *s, gboolean repeat);
gboolean statusbar_get_repeat      (Statusbar *s);

#endif /* __STATUSBAR_H */
