/*
 *  Copyright (C) 2001 Matthew Mueller
 *            (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: state.c,v 1.5 2002/04/01 14:49:23 jbaayen Exp $
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtkpaned.h>
#include <gtk/gtkwindow.h>
#include <gtk/gtktreeview.h>
#include <libgnomeui/gnome-app.h>
#include <bonobo/bonobo-dock.h>
#include <bonobo/bonobo-dock-layout.h>

#include "state.h"
#include "eel-gconf-extensions.h"

#define CONF_STATE_PATH          "/apps/rhythmbox/State"

/**
 * state_save_window_state: save the window dimensions
 */
void
state_save_window_state (GtkWidget *window, const gchar *name)
{
	gint x, y, width, height;
	gchar *buf = NULL;

	gdk_window_get_root_origin (window->window, &x, &y);
	gdk_window_get_size (window->window, &width, &height);

	buf = g_strdup_printf (CONF_STATE_PATH "/%s/x",name);
	eel_gconf_set_integer (buf, x);
	g_free (buf);

	buf = g_strdup_printf (CONF_STATE_PATH "/%s/y",name);
	eel_gconf_set_integer (buf, y);
	g_free (buf);

	buf = g_strdup_printf (CONF_STATE_PATH "/%s/width",name);
        eel_gconf_set_integer (buf, width);
	g_free (buf);

	buf = g_strdup_printf (CONF_STATE_PATH "/%s/height",name);
	eel_gconf_set_integer (buf, height);
	g_free (buf);
}

/**
 * state_load_window_state: load the window state
 */
void
state_load_window_state (GtkWidget *window, const gchar *name)
{
	gchar *buf;
	gint x, y, width, height;
	
	buf = g_strdup_printf (CONF_STATE_PATH "/%s/x",name);
	x = eel_gconf_get_integer (buf);
	g_free (buf);

	buf = g_strdup_printf (CONF_STATE_PATH "/%s/y",name);
	y = eel_gconf_get_integer (buf);
	g_free (buf);

	buf = g_strdup_printf (CONF_STATE_PATH "/%s/width",name);
        width = eel_gconf_get_integer (buf);
	g_free (buf);

	buf = g_strdup_printf (CONF_STATE_PATH "/%s/height",name);
	height = eel_gconf_get_integer (buf);
	g_free (buf);


	if (!(x == -1 && y == -1))
		gtk_widget_set_uposition (window, x, y);

	if (!(width == -1 && height == -1))
		gtk_window_set_default_size (GTK_WINDOW (window),
					     width, height);

}

/**
 * state_save_dock_layout: save the dock layout
 */
void
state_save_dock_layout (GtkWidget *app, const gchar *name)
{
	BonoboDockLayout *dl =
		bonobo_dock_get_layout (BONOBO_DOCK (GNOME_APP (app)->dock));
	gchar *layout = bonobo_dock_layout_create_string (dl);
	gchar *buf = g_strdup_printf (CONF_STATE_PATH "/%s/dock_layout", name);

	eel_gconf_set_string (buf, layout);

	g_free (buf);
	g_free (layout);
	g_object_unref (G_OBJECT (dl));
}

/**
 * state_load_dock_layout: load the dock layout
 * FIXME
 */
void
state_load_dock_layout (GtkWidget *app, const gchar *name)
{
	gchar *buf = g_strdup_printf (CONF_STATE_PATH "/%s/dock_layout", name);
	gchar *layout = eel_gconf_get_string (buf);

	if (layout)
	{
		bonobo_dock_layout_parse_string (GNOME_APP (app)->layout, layout);
	}

	g_free (buf);
	g_free (layout);
}

/**
 * state_load_pane_pos: load the paned position
 */
void
state_load_pane_pos (GtkWidget *pane, const gchar *name)
{
	if (pane != NULL)
	{
		gint pane_pos;
		gchar *buf = g_strdup_printf (CONF_STATE_PATH "/%s", name);
		pane_pos = eel_gconf_get_integer (buf);
		g_free (buf);

		if (pane_pos != -1)
			gtk_paned_set_position (GTK_PANED (pane), pane_pos);
	}
}

/**
 * state_save_pane_pos: save the paned position
 */
void
state_save_pane_pos (GtkWidget *pane, const gchar *name)
{
	if (pane != NULL)
	{
		gchar *buf = g_strdup_printf (CONF_STATE_PATH "/%s", name);
		eel_gconf_set_integer (buf, GTK_PANED (pane)->child1_size);
		g_free (buf);
	}
}

/**
 * state_save_treeview_layout: save the treeview layout
 * FIXME
 */
void
state_save_treeview_layout (GtkWidget *view, const gchar *name)
{
#if 0
	GList *l, *list = gtk_tree_view_get_columns (GTK_TREE_VIEW (view));
	gchar *buf;
	gint i = 0;

	for (l = list; l != NULL; l = g_list_next (l))
	{
		GtkTreeViewColumn *col = (GtkTreeViewColumn *) l->data;
		gint origcol = GPOINTER_TO_INT
			(g_object_get_data (G_OBJECT (col), "original_column"));

		buf = g_strdup_printf (CONF_STATE_PATH "/%s/%d/column", name, origcol);
		eel_gconf_set_integer (buf, i);
		g_free (buf);

		buf = g_strdup_printf (CONF_STATE_PATH "/%s/%d/width", name, origcol);
		eel_gconf_set_integer (buf, gtk_tree_view_column_get_width (col));
		g_free (buf);

		buf = g_strdup_printf (CONF_STATE_PATH "/%s/%d/sort_order", name, origcol);
		if (gtk_tree_view_column_get_sort_indicator (col))
		{
			eel_gconf_set_integer (buf,
					       gtk_tree_view_column_get_sort_order (col));
		}
		else
		{
			eel_gconf_set_integer (buf, -1);
		}
		g_free (buf);

		i++;
	}

	g_list_free (list);
#endif
}

/**
 * state_load_treeview_layout: load the treeview layout
 * FIXME
 */
void
state_load_treeview_layout (GtkWidget *view, const gchar *name)
{
#if 0
	GList *l, *list = gtk_tree_view_get_columns (GTK_TREE_VIEW (view));
	gchar *buf;
	gint i = g_list_length (list) - 1;

	for (l = g_list_reverse (list); l != NULL; l = g_list_next (l))
	{
		GtkTreeViewColumn *col = (GtkTreeViewColumn *) l->data;
		GtkSortType order;

		if (gtk_tree_view_column_get_reorderable (col))
		{
			GtkTreeViewColumn *c;
			buf = g_strdup_printf (CONF_STATE_PATH "/%s/%d/column", name, i);
			c = gtk_tree_view_get_column (GTK_TREE_VIEW (view),
						      eel_gconf_get_integer (buf) - 1);
			gtk_tree_view_move_column_after (GTK_TREE_VIEW (view), col, c);
			g_free (buf);
		}

		if (gtk_tree_view_column_get_resizable (col))
		{
			gint width;
			buf = g_strdup_printf (CONF_STATE_PATH "/%s/%d/width", name, i);
			width = eel_gconf_get_integer (buf);
			if (width != -1)
			{
				col->resized_width = width;
				col->use_resized_width = TRUE;
			}
			g_free (buf);
		}

		buf = g_strdup_printf (CONF_STATE_PATH "/%s/%d/sort_order", name, i);
		order = eel_gconf_get_integer (buf);
		g_free (buf);
		if (order != -1)
		{
			gtk_tree_view_column_set_sort_indicator (col, TRUE);
			gtk_tree_view_column_set_sort_order (col, order);
			gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
				(gtk_tree_view_get_model (GTK_TREE_VIEW (view))), i, order);
		}

		i--;
	}

	g_list_free (list);
#endif
}
